@@ -65,6 +65,7 @@ copies.
  ** 95/03/23  V 3.01  E.B  gnuplot ascii format added
  **/
 
+#include "pendef.h"
 
 /**
  ** Working with Pure C (the official descendant of Borland's
@@ -137,11 +138,13 @@ copies.
 #endif
 
 #define	ESC	'\033'
-#define	CR	'\015'
+#define	_CR	'\015'
 #define	FF	'\014'
 #define	LF	'\012'
 #define	BEL	'\007'
 
+#define MM_TO_PS_POINT 2.834646
+
 #define	MAX_LB_LEN	150	/* Max num of chars per label	*/
 
 #define MAXPOLY 20480  /* Size of polygon vertex buffer */
@@ -171,7 +174,7 @@ typedef unsigned char	Byte;
 typedef	enum{
 	XX_CAD, XX_CS, XX_DXF, XX_EM, XX_EMF, XX_EMP, XX_EPIC, XX_EPS, XX_ESC2, XX_FIG, XX_GPT, XX_HPGL, 
         XX_ILBM, XX_IMG, XX_JPG,
-	XX_MF, XX_PBM, XX_PCL, XX_PCX, XX_PAC, XX_PDF, XX_PIC, XX_PNG, XX_PRE, 
+	XX_MF, XX_NC, XX_PBM, XX_PCL, XX_PCX, XX_PAC, XX_PDF, XX_PIC, XX_PNG, XX_PRE, 
 	XX_RGIP, XX_SVG, XX_TIFF, XX_TERM	/* Dummy: terminator	*/
 } hp2xx_mode;
 
@@ -208,7 +211,7 @@ typedef	struct {
 
 
 typedef enum {
-	NOP, MOVE_TO, DRAW_TO, PLOT_AT, SET_PEN, DEF_PW, DEF_PC, CMD_EOF
+	NOP, MOVE_TO, DRAW_TO, PLOT_AT, SET_PEN, DEF_PW, DEF_PC, DEF_LA, CMD_EOF
 } PlotCmd;
 
 
@@ -249,8 +252,10 @@ typedef struct			/* Corresponding option(s)	*/
    int	vga_width;		/* (internally needed)		*/
    int	dpi_x, dpi_y;		/* -d dpi_x  -y dpi_y		*/
    int	init_p;			/* -i  (PCL only)		*/
+   int  init_p3gui;		/* -I  (PCL only)		*/
    int	formfeed;		/* -F  (PCL only)		*/
    int  specials;		/* -s specials  (PCL only)	*/
+   int  pagecount;		/* for naming multi-page output */
    char	  *outfile;		/* -f outfile ("-" = stdout)	*/
    double xmin,ymin, xmax,ymax; /* (internally needed)		*/
    double xoff, yoff;		/* Internal copies from IN_PAR	*/
@@ -258,6 +263,7 @@ typedef struct			/* Corresponding option(s)	*/
    double HP_to_xdots;		/* (internally needed)		*/
    double HP_to_ydots;		/* (internally needed)		*/
    PicBuf *picbuf;		/* (internally needed)		*/
+   double zengage,zretract;	/* z min/max for 3d (currently only nc) */
 }	OUT_PAR;
 
 
@@ -274,7 +280,8 @@ typedef struct			/* Corresponding option(s)	*/
    int	 quiet;			/* -q				*/
    int   nofill;		/* -n				*/
    int   no_ps;			/* -N				*/
-   int	 maxpensize;		/* (internally needed)		*/
+   int         extraclip;       /* -e extraclip                 */
+   PEN_W maxpensize;		/* (internally needed)		*/
    int	 is_color;		/* (internally needed)		*/
    int	 maxcolor;		/* (internally needed)		*/
    FILE	 	*td;		/* (internally needed)		*/
@@ -333,9 +340,10 @@ void	PError		(const char*);
 void	SilentWait	(void);
 void	NormalWait	(void);
 
-void	plot_user_char	(FILE *);
+void	plot_user_char	(FILE *, short);
 void	read_HPGL	(GEN_PAR*, const IN_PAR*);
 void	adjust_input_transform	(const GEN_PAR*, const IN_PAR*, OUT_PAR*);
+void	adjust_input_transform	(const GEN_PAR*, const IN_PAR*, OUT_PAR*);
 PlotCmd	PlotCmd_from_tmpfile	(void);
 void	HPGL_Pt_from_tmpfile	(HPGL_Pt *);
 void	Pen_action_to_tmpfile	(PlotCmd, const HPGL_Pt*, int);
@@ -407,16 +415,8 @@ void fill (HPGL_Pt polygon[MAXPOLY], int numpoints, HPGL_Pt P1, HPGL_Pt P2,
 
 /*std_main*/
 void action_oldstyle(GEN_PAR *, IN_PAR *, OUT_PAR *);
-/*to_eps*/
-void ps_end(FILE *);
-void ps_stroke_and_move_to(HPGL_Pt *, FILE *);
-void ps_set_linewidth(double, HPGL_Pt *, FILE *);
-void ps_set_color(double, double, double, HPGL_Pt *, FILE *);
-void ps_line_to(HPGL_Pt *, char, FILE *);
-char *Getdate(void);
-void ps_init(const GEN_PAR *, const OUT_PAR *, FILE *, int);
 /*to_fig*/
-void fig_poly_end(int, int, FILE *, int, long *, long *);
+void fig_poly_end(PEN_W, int, int, int, FILE *, int, long *, long *);
 /*to_x11*/
 void win_close(void);
            
